==> haskell-aeson-yaml-1.1.0.0-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-yaml
version:              1.1.0.0
visibility:           public
id:                   aeson-yaml-1.1.0.0-205VgZeTubQFjMS4PqXecf
key:                  aeson-yaml-1.1.0.0-205VgZeTubQFjMS4PqXecf
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  09e28e176afb93679e1932d7424f47ec
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-8.10.2/site-local/aeson-yaml-1.1.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/aeson-yaml-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/aeson-yaml-1.1.0.0
hs-libraries:         HSaeson-yaml-1.1.0.0-205VgZeTubQFjMS4PqXecf
depends:
    aeson-1.5.4.0-thRxPPoh7zGG5olCVnCMS base-4.14.1.0
    bytestring-0.10.10.0 text-1.2.3.2
    unordered-containers-0.2.12.0-77J5u5JaDzyKBIiI2wOCQf
    vector-0.12.1.2-9Tv6x03Z1JF7LL7lw4fTei

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-yaml-1.1.0.0-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-yaml
version:              1.1.0.0
visibility:           public
id:                   aeson-yaml-1.1.0.0-CXqlmbUxnaQGfXkhWs8QjG
key:                  aeson-yaml-1.1.0.0-CXqlmbUxnaQGfXkhWs8QjG
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  a1e98e42e42fdb78878bcf0ea5e914f5
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-8.10.2/site-local/aeson-yaml-1.1.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/aeson-yaml-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/aeson-yaml-1.1.0.0
hs-libraries:         HSaeson-yaml-1.1.0.0-CXqlmbUxnaQGfXkhWs8QjG
depends:
    aeson-1.5.4.0-EKD5HdaQvhNEWBNwoih2VS base-4.14.1.0
    bytestring-0.10.10.0 text-1.2.3.2
    unordered-containers-0.2.12.0-L7e0ebfosZDK7txbADKTIQ
    vector-0.12.1.2-E9lCzNvHLtkKefSxgFoNMj

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
